#[non_exhaustive]pub enum ParseErrorKind {
InvalidFormat,
OutOfBounds,
InvalidAddress,
InvalidLoadCommand,
LimitExceeded,
Unsupported,
Validation,
}Expand description
Stable category for a structural parse failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidFormat
The input does not encode a recognized or internally consistent format.
OutOfBounds
A byte range lies outside the supplied input.
InvalidAddress
An address or offset cannot be mapped safely.
InvalidLoadCommand
A load command is malformed.
LimitExceeded
A safe parser limit was exhausted.
Unsupported
The input is structurally valid but unsupported by this parser.
Validation
Strict structural validation rejected the parsed model.