pub struct MaterializedImage { /* private fields */ }Expand description
A reconstructed Mach-O file and its source-coordinate map.
Implementations
Sourceimpl MaterializedImage
impl MaterializedImage
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Consume the result and return its parseable bytes.
Sourcepub fn mappings(&self) -> &[FileRvaMapping]
pub fn mappings(&self) -> &[FileRvaMapping]
File-to-RVA mappings in file order.
Sourcepub fn synthetic_padding(&self) -> &[Range<u64>]
pub fn synthetic_padding(&self) -> &[Range<u64>]
Unbacked file ranges filled with zero solely to preserve file layout.
Consumers must not cite these ranges as captured evidence.